package com.ruoyi.common.utils.excel;

import com.alibaba.excel.EasyExcel;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.List;

/**
 * Excel工具类
 */
public class ExcelReadUtil {

    public static <T> List<T> read(MultipartFile file, Class<T> clazz) throws IOException {
        return read(file, clazz, 1);
    }

    /**
     * 读取Excel文件
     *
     * @param file          文件
     * @param clazz         目标数据类型
     * @param headRowNumber 表头所在行数
     * @throws IOException 读取文件异常
     */
    public static <T> List<T> read(MultipartFile file, Class<T> clazz, int headRowNumber) throws IOException {
        ImportListener<T> listener = new ImportListener<>();

        // 使用EasyExcel读取Excel文件内容
        EasyExcel.read(file.getInputStream(), clazz, listener).sheet() // 默认读取第一个sheet
                .headRowNumber(headRowNumber) // 指定表头所在行数
                .doRead(); // 执行读取操作

        return listener.getDataList();
    }

    public static <T, R> List<R> read(MultipartFile file, Class<T> tClazz, Class<R> rClazz) throws IOException{
        return read(file, tClazz, rClazz, 1);
    }

    /**
     * 读取Excel文件，并转换数据类型
     *
     * @param file          文件
     * @param tClazz        源数据类型
     * @param rClazz        目标数据类型
     * @param headRowNumber 表头所在行数
     * @throws IOException 读取文件异常
     */
    public static <T, R> List<R> read(MultipartFile file, Class<T> tClazz, Class<R> rClazz, int headRowNumber) throws IOException {
        DataConverter<T, R> dataConverter;
        try {
            T t = tClazz.getDeclaredConstructor().newInstance();
            Method instanceMethod = tClazz.getDeclaredMethod("getConverter");

            dataConverter = (DataConverter<T, R>) instanceMethod.invoke(t);
        } catch (InstantiationException | IllegalAccessException | NoSuchMethodException |
                 InvocationTargetException e) {
            throw new RuntimeException("实例化数据转化类失败: " + tClazz.getName(), e);
        }

        TranslateImportListener<T, R> listener = new TranslateImportListener<>(dataConverter);

        // 使用EasyExcel读取Excel文件内容
        EasyExcel.read(file.getInputStream(), tClazz, listener).sheet() // 默认读取第一个sheet
                .headRowNumber(headRowNumber) // 指定表头所在行数
                .doRead(); // 执行读取操作

        return listener.getDataList();
    }
}
