package com.ruoyi.project.VRdemo.controller;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.excel.EasyExcel;
import com.ruoyi.common.utils.excel.ExcelReadUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Anonymous;
import com.ruoyi.project.VRdemo.domain.imData.EconomyImData;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.VRdemo.domain.Economy;
import com.ruoyi.project.VRdemo.service.IEconomyService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 东南亚经济统计Controller
 *
 * @author ruoyi
 * @date 2024-10-06
 */
@RestController
@RequestMapping("/vr/economy")
public class EconomyController extends BaseController {

    private final IEconomyService economyService;

    public EconomyController(@Autowired IEconomyService economyService) {
        this.economyService = economyService;
    }

    /**
     * 查询东南亚经济统计列表
     */
    @Anonymous
    @GetMapping("/list")
    public AjaxResult list(Economy economy) {
        List<Economy> list = economyService.selectEconomyList(economy);

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 200);
        ajaxResult.put("rows", list);
        ajaxResult.put("total", list.size());
        return ajaxResult;

    }

    /**
     * 查询分页列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @GetMapping("/pageList")
    public TableDataInfo pageList(Economy economy) {
        startPage();
        List<Economy> list = economyService.selectEconomyList(economy);
        return getDataTable(list);
    }

    /**
     * 获取东南亚经济统计详细信息
     */
    @Anonymous
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(economyService.selectEconomyById(id));
    }

    /**
     * 新增东南亚经济统计
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "东南亚经济统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Economy economy) {
        return toAjax(economyService.insertEconomy(economy));
    }

    /**
     * 修改东南亚经济统计
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "东南亚经济统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Economy economy) {
        return toAjax(economyService.updateEconomy(economy));
    }

    /**
     * 删除东南亚经济统计
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "东南亚经济统计", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(economyService.deleteEconomyByIds(ids));
    }

    /**
     * 导出东南亚经济统计列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "东南亚经济统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Economy economy) {
        List<Economy> list = economyService.selectEconomyList(economy);
        ExcelUtil<Economy> util = new ExcelUtil<>(Economy.class);
        util.exportExcel(response, list, "东南亚经济统计数据");
    }

    /**
     * 下载导入模板
     */
    @Anonymous
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) throws IOException {
        List<EconomyImData> dataList = new ArrayList<>();
        EasyExcel.write(response.getOutputStream(), EconomyImData.class).sheet("Sheet1").doWrite(dataList);
    }

    /**
     * 导入数据
     */
    @Anonymous
    @PostMapping("/import")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws IOException {

        List<Economy> list = ExcelReadUtil.read(file, EconomyImData.class, Economy.class);

        // 调用服务层方法进行数据导入处理
        String message = economyService.importData(list, updateSupport);

        // 返回成功响应，携带导入结果信息
        return AjaxResult.success(message);
    }
}
