package com.ruoyi.project.VRdemo.controller;



import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.common.utils.file.FileUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;

import com.ruoyi.framework.config.RuoYiConfig;
import com.ruoyi.framework.config.ServerConfig;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.VRdemo.domain.FileUpload;
import com.ruoyi.project.VRdemo.service.IFileUploadService;
import org.apache.commons.io.FilenameUtils;

import org.springframework.beans.factory.annotation.Autowired;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;

import java.util.List;

@RestController
@RequestMapping("/VRdemo/file")
public class FileUploadController extends BaseController {
    @Autowired
    private IFileUploadService fileUploadService;
    @Autowired
    private ServerConfig serverConfig;

    /**
     * 查询data列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,company')")
    @GetMapping("/list")
    public TableDataInfo list(FileUpload fileUpload) {
        startPage();
        List<FileUpload> list = fileUploadService.selectFileUploadList(fileUpload);
        return getDataTable(list);
    }

    /**
     * 导出data列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,company')")
//    @Log(title = "data", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FileUpload fileUpload) {
        List<FileUpload> list = fileUploadService.selectFileUploadList(fileUpload);
        ExcelUtil<FileUpload> util = new ExcelUtil<FileUpload>(FileUpload.class);
        util.exportExcel(response, list, "data数据");
    }

    /**
     * 获取data详细信息
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,company')")
    @GetMapping(value = "/{fileid}")
    public AjaxResult getInfo(@PathVariable("fileid") Long fileid) {
        return success(fileUploadService.selectFileUploadByfileid(fileid));
    }

    /**
     * 新增data
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,company')")
//    @Log(title = "data", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FileUpload FileUpload) {
        if (FileUpload.getPath() != null && FileUpload.getPath() != "") {
            return toAjax(fileUploadService.insertFileUpload(FileUpload));
        } else {
            return AjaxResult.error("请选择图片！");
        }
    }

    /**
     * 修改data
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,company')")
//    @Log(title = "data", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FileUpload FileUpload) {
        return toAjax(fileUploadService.updateFileUpload(FileUpload));
    }

    /**
     * 通用上传请求（单个）
     */
    @PostMapping("/upload")
    public AjaxResult uploadFile(MultipartFile file) throws Exception {
        try {
            String extension = FilenameUtils.getExtension(file.getOriginalFilename());
            String filePath;

            if (extension.equalsIgnoreCase("pdf")) {
                filePath = RuoYiConfig.getuploadPdf();
            } else if (extension.equalsIgnoreCase("doc") || extension.equalsIgnoreCase("docx")) {
                filePath = RuoYiConfig.getuploadWord();
            } else {
                filePath = RuoYiConfig.getUploadPath();
            }

            String fileName = FileUploadUtils.upload(filePath, file);
            String url = serverConfig.getUrl() + fileName;

            AjaxResult ajax = AjaxResult.success();
            ajax.put("url", url);
            ajax.put("fileName", fileName);
            ajax.put("newFileName", FileUtils.getName(fileName));
            ajax.put("originalFilename", file.getOriginalFilename());

            FileUpload fileUpload = new FileUpload();
            fileUpload.setUrl(url);
            fileUploadService.updateFileUpload(fileUpload);
            return ajax;
        } catch (Exception e) {
            return AjaxResult.error(e.getMessage());
        }
    }

    //删除
    @DeleteMapping("/{fileid}")
    public String deleteFile(@PathVariable("fileid") String fileid) {
        try {
            Long fileId = Long.parseLong(fileid);
            System.out.println(fileId);
            boolean success = fileUploadService.deleteFile(fileId);
            if (success) {
                return "文件删除成功.";
            } else {
                return "文件删除失败.";
            }
        } catch (NumberFormatException e) {
            return "文件格式错误";
        }
    }

//只删除单一文件
    @PostMapping("/delete")
    public AjaxResult deleteOnlyFile(@RequestBody String fileId) {
        Long fileid = Long.parseLong(fileId);
        System.out.println("1");
        boolean result = fileUploadService.updateOnlyFile(fileid);
        if (result) {
            return AjaxResult.success("删除成功");
        } else {
            return AjaxResult.error("删除失败或图片路径存在异常");
        }
    }
}
