package com.ruoyi.project.VRdemo.controller;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.excel.EasyExcel;
import com.ruoyi.common.utils.excel.ExcelReadUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Anonymous;
import com.ruoyi.project.VRdemo.domain.imData.ThesisImData;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.VRdemo.domain.Thesis;
import com.ruoyi.project.VRdemo.service.IThesisService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 论文Controller
 *
 * @author ruoyi
 * @date 2024-06-23
 */
@RestController
@RequestMapping("/vr/thesis")
public class ThesisController extends BaseController {

    private final IThesisService thesisService;

    public ThesisController(@Autowired IThesisService thesisService) {
        this.thesisService = thesisService;
    }

    /**
     * 查询论文列表
     */
    @Anonymous
    @GetMapping("/list")
    public AjaxResult list(Thesis thesis) {
        List<Thesis> list = thesisService.selectThesisList(thesis);

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 200);
        ajaxResult.put("rows", list);
        ajaxResult.put("total", list.size());
        return ajaxResult;
    }

    /**
     * 查询分页列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @GetMapping("/pageList")
    public TableDataInfo pageList(Thesis thesis) {
        startPage();
        List<Thesis> list = thesisService.selectThesisList(thesis);
        return getDataTable(list);
    }

    /**
     * 获取论文详细信息
     */
    @Anonymous
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(thesisService.selectThesisById(id));
    }

    /**
     * 新增论文
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "论文", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Thesis thesis) {
        return toAjax(thesisService.insertThesis(thesis));
    }

    /**
     * 修改论文
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "论文", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Thesis thesis) {
        return toAjax(thesisService.updateThesis(thesis));
    }

    /**
     * 删除论文
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "论文", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(thesisService.deleteThesisByIds(ids));
    }

    /**
     * 导出论文列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "论文", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Thesis thesis) {
        List<Thesis> list = thesisService.selectThesisList(thesis);
        ExcelUtil<Thesis> util = new ExcelUtil<>(Thesis.class);
        util.exportExcel(response, list, "论文数据");
    }

    /**
     * 下载导入模板
     */
    @Anonymous
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) throws IOException {
        List<ThesisImData> dataList = new ArrayList<>();
        EasyExcel.write(response.getOutputStream(), ThesisImData.class).sheet("Sheet1").doWrite(dataList);
    }

    /**
     * 导入数据
     */
    @Anonymous
    @PostMapping("/import")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws IOException {

        List<Thesis> list = ExcelReadUtil.read(file, ThesisImData.class, Thesis.class);

        // 调用服务层方法进行数据导入处理
        String message = thesisService.importData(list, updateSupport);

        // 返回成功响应，携带导入结果信息
        return AjaxResult.success(message);
    }
}
