package com.ruoyi.project.VRdemo.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.VRdemo.mapper.ConsultationMapper;
import com.ruoyi.project.VRdemo.domain.Consultation;
import com.ruoyi.project.VRdemo.service.IConsultationService;

/**
 * 博雅集南洋资讯检索Service业务层处理
 *
 * @author ruoyi
 */
@Service
public class ConsultationServiceImplImpl implements IConsultationService {

    private final ConsultationMapper consultationMapper;

    public ConsultationServiceImplImpl(@Autowired ConsultationMapper consultationMapper) {
        this.consultationMapper = consultationMapper;
    }

    /**
     * 查询博雅集南洋资讯检索
     *
     * @param id 博雅集南洋资讯检索主键
     * @return 博雅集南洋资讯检索
     */
    @Override
    public Consultation selectConsultationById(Long id) {
        return consultationMapper.selectConsultationById(id);
    }

    /**
     * 查询博雅集南洋资讯检索列表
     *
     * @param consultation 博雅集南洋资讯检索
     * @return 博雅集南洋资讯检索
     */
    @Override
    public List<Consultation> selectConsultationList(Consultation consultation) {
        return consultationMapper.selectConsultationList(consultation);
    }

    /**
     * 新增博雅集南洋资讯检索
     *
     * @param consultation 博雅集南洋资讯检索
     * @return 结果
     */
    @Override
    public int insertConsultation(Consultation consultation) {
        consultation.setCreateTime(DateUtils.getNowDate());
        return consultationMapper.insertConsultation(consultation);
    }

    /**
     * 修改博雅集南洋资讯检索
     *
     * @param consultation 博雅集南洋资讯检索
     * @return 结果
     */
    @Override
    public int updateConsultation(Consultation consultation) {
        consultation.setUpdateTime(DateUtils.getNowDate());
        return consultationMapper.updateConsultation(consultation);
    }

    /**
     * 批量删除博雅集南洋资讯检索
     *
     * @param ids 需要删除的博雅集南洋资讯检索主键
     * @return 结果
     */
    @Override
    public int deleteConsultationByIds(Long[] ids) {
        return consultationMapper.deleteConsultationByIds(ids);
    }

    /**
     * 删除博雅集南洋资讯检索信息
     *
     * @param id 博雅集南洋资讯检索主键
     * @return 结果
     */
    @Override
    public int deleteConsultationById(Long id) {
        return consultationMapper.deleteConsultationById(id);
    }

    @Override
    public String importData(List<Consultation> dataList, boolean updateSupport) {
        BulkImportService<Consultation> importService = new BulkImportService<Consultation>() {
            @Override
            protected Long checkExistingItem(Consultation item) {
                Consultation consultation = consultationMapper.selectConsultationByTitle(item.getChineseName(), item.getEnglishName());
                return consultation == null ? 0L : consultation.getId();
            }

            @Override
            protected boolean updateItem(Consultation item, Long id) {
                item.setId(id);
                item.setUpdateBy(SecurityUtils.getLoginUser().getUsername());
                item.setUpdateTime(DateUtils.getNowDate());
                return consultationMapper.updateConsultation(item) > 0;
            }

            @Override
            protected boolean executeBatch(List<Consultation> batchDataList) {
                return consultationMapper.insertConsultationDataList(batchDataList) > 0;
            }

            @Override
            protected String getItemTitle(Consultation item) {
                return item.getTitle();
            }
        };

        return importService.importData(dataList, updateSupport);
    }

}
