package com.ruoyi.project.VRdemo.service.impl;

import com.ruoyi.common.constant.UserConstants;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;

import com.ruoyi.project.VRdemo.domain.NoticeData;
import com.ruoyi.project.VRdemo.domain.imData.NoticeImData;
import com.ruoyi.project.VRdemo.domain.vo.NoticeDataVo;
import com.ruoyi.project.VRdemo.mapper.DataExcelMapper;
import com.ruoyi.project.VRdemo.mapper.NoticeDataMapper;
import com.ruoyi.project.VRdemo.service.INoticeDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@Service
public class NoticeDataServiceImpl implements INoticeDataService {
    private static final int BATCH_COUNT = 100;
    private static final Logger logger = LoggerFactory.getLogger(NoticeImData.class);
    @Autowired
    private NoticeDataMapper noticeDataMapper;

    @Autowired
    private DataExcelMapper dataExcelMapper;

    /**
     * 查询notice
     *
     * @param id notice主键
     * @return notice
     */
    @Override
    public NoticeData selectNoticeDataById(Long id) {
        return noticeDataMapper.selectNoticeDataById(id);
    }

    /**
     * 查询notice列表
     *
     * @param noticeData notice
     * @return notice
     */
    @Override
    public List<NoticeData> selectNoticeDataList(NoticeData noticeData) {
        return noticeDataMapper.selectNoticeDataList(noticeData);
    }

    /**
     * 新增notice
     *
     * @param noticeData notice
     * @return 结果
     */
    @Override
    public int insertNoticeData(NoticeData noticeData) {
        noticeData.setCreateTime(DateUtils.getNowDate());
        return noticeDataMapper.insertNoticeData(noticeData);
    }
    /**
     * 校验用户名称是否唯一
     *
     * @param noticeData 用户信息
     * @return 结果
     */
    @Override
    public boolean checkUserNameUnique(NoticeData noticeData)
    {
        Long userId = StringUtils.isNull(noticeData.getId()) ? -1L : noticeData.getId();
        NoticeData info = noticeDataMapper.checkUserNameUnique(noticeData.getTitle());
        if (StringUtils.isNotNull(info) && info.getId().longValue() != userId.longValue())
        {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }
    /**
     * 修改notice
     *
     * @param noticeData notice
     * @return 结果
     */
    @Override
    public int updateNoticeData(NoticeData noticeData) {
        noticeData.setUpdateTime(DateUtils.getNowDate());
        return noticeDataMapper.updateNoticeData(noticeData);
    }

    /**
     * 批量删除notice
     *
     * @param ids 需要删除的notice主键
     * @return 结果
     */
    @Override
    public int deleteNoticeDataByIds(Long[] ids) {
        return noticeDataMapper.deleteNoticeDataByIds(ids);
    }

    /**
     * 删除notice信息
     *
     * @param id notice主键
     * @return 结果
     */
    @Override
    public int deleteNoticeDataById(Long id) {
        return noticeDataMapper.deleteNoticeDataById(id);
    }

    @Override
    public List<NoticeData> selectNoticeDataListVo(NoticeDataVo noticeDataVo) {
        return noticeDataMapper.selectNoticeDataListVo(noticeDataVo);
    }

    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED)
    public String importNotice(List<NoticeImData> noticeList, Boolean updateSupport) {
        if (StringUtils.isNull(noticeList) || noticeList.size() == 0) {
            logger.error("导入用户数据为空！");
            throw new ServiceException("导入用户数据不能为空！");
        }
        List<NoticeImData> batchDataList = new ArrayList<>();
        int successNum = 0;
        int failureNum = 0;
        StringBuilder successMsg = new StringBuilder();
        StringBuilder failureMsg = new StringBuilder();
        // 遍历用户数据列表，逐条处理数据
        for (NoticeImData notice : noticeList) {
            try {
                // 对每一条数据进行处理
                // 根据title字段判断数据合法性
                if (StringUtils.isEmpty(notice.getTitle())) {
                    throw new ServiceException("模板标题不能为空！");
                }
                // 如果更新支持，检查数据库中是否存在相同的记录，如果存在，则进行更新操作
                // 判断数据库中是否存在相同标题的记录
                String titleAsString = notice.getTitle();
                NoticeImData existingNotice = dataExcelMapper.selectNoticeByTitle(titleAsString);

                // 在处理开展方式字段的代码
                String holdingType = notice.getHolding_type();
                int holdingTypeValue;

                if ("线上".equals(holdingType)) {
                    holdingTypeValue = 1;
                } else if ("线下".equals(holdingType)) {
                    holdingTypeValue = 2;
                } else if ("线上线下相结合".equals(holdingType)) {
                    holdingTypeValue = 3;
                }else {
                    failureNum++;
                    failureMsg.append("导入失败，模板标题为：").append(notice.getTitle())
                            .append("，开展方式只能输入'线上'或'线下'或‘线上线下相结合’").append("\n");
                    continue;
                }

                if (existingNotice != null && updateSupport) {
                    //更新中的开展方式转换
                    if ("线上".equals(holdingType)) {
                        holdingTypeValue = 1;
                    } else if ("线下".equals(holdingType)) {
                        holdingTypeValue = 2;
                    } else if ("线上线下相结合".equals(holdingType)) {
                        holdingTypeValue = 3;
                    } else {
                        failureNum++;
                        failureMsg.append("导入失败，模板标题为：").append(notice.getTitle())
                                .append("，开展方式只能输入'线上'或'线下'或‘线上线下相结合’").append("\n");
                        continue;
                    }

                    // 设置转换后的值到对象的开展方式字段中
                    notice.setHolding_type(String.valueOf(holdingTypeValue));
                    // 更新操作
                    dataExcelMapper.updateImNotice(notice);
                    successNum++;
                    successMsg.append("成功更新数据：").append(notice.getTitle()).append("\n");
                } else {
                    logger.debug("开始执行插入操作，数据列表大小：{}", batchDataList.size());

                    // 设置企业ID默认值
                    notice.setCompany_id(3L);

                    // 设置转换后的值到对象的开展方式字段中
                    notice.setHolding_type(String.valueOf(holdingTypeValue));


                    // 检查是否已经存在于 batchDataList 中，避免重复插入
                    if (!batchDataList.contains(notice)) {
                        batchDataList.add(notice);
                    }
                    // 判断是否达到BATCH_COUNT，或者已经是最后一个数据
                    if (batchDataList.size() >= BATCH_COUNT || noticeList.indexOf(notice) == noticeList.size() - 1) {
                        // 执行批量插入操作
                        List<NoticeImData> insertList = new ArrayList<>(batchDataList); // 复制列表
                        dataExcelMapper.insertNoticeDataList(insertList); // 使用复制的列表进行插入
                        successNum += insertList.size();
                        for (NoticeImData insertedNotice : insertList) {
                            successMsg.append("成功导入数据：").append(insertedNotice.getTitle()).append("\n");
                        }
                        batchDataList.clear();


                    }
                }
            } catch (Exception e) {
                // 处理导入失败的情况
                failureNum++;
                failureMsg.append("导入失败，模板标题为：").append(notice.getTitle()).append("\n");
            }
        }
        // 判断是否有导入失败的数据
        if (failureNum > 0) {
            failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据格式不正确或插入数据库出错，错误如下：\n");
            throw new ServiceException(failureMsg.toString());
        } else {
            // 若全部数据导入成功，则返回成功导入的信息
            successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：\n");

        }
        return successMsg.toString();
    }
}